==> e107_0.7.23_full.tar.gz: e107_languages/English/lan_usersettings.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_usersettings.php,v $
|     $Revision: 11553 $
|     $Date: 2010-05-25 14:30:34 -0500 (Tue, 25 May 2010) $
|     $Author: mcfly_e107 $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "User Settings");

define("LAN_7", "Display Name: ");
define("LAN_8", "the name displayed on site");
define("LAN_9", "Username: ");
define("LAN_10", "the name you use to login to the site");
define("LAN_11", "the name you use to login to the site - this cannot be changed, please contact an administrator if it needs to be changed for security purposes");

define("LAN_20", "Error");
define("LAN_105", "The two passwords do not match");
define("LAN_106", "That doesn't appear to be a valid email address");
define("LAN_112", "Email Address: ");
define("LAN_113", "Hide email address?: ");
define("LAN_114", "This will prevent your email address from being displayed on site");
//define("LAN_115", "ICQ Number: ");
//define("LAN_116", "AIM Address: ");
//define("LAN_117", "MSN Messenger: ");
//define("LAN_118", "Birthday: ");
//define("LAN_119", "Location: ");
define("LAN_120", "Signature: ");
//define("LAN_121", "Avatar: ");
define("LAN_122", "Timezone:");
//define("LAN_144", "Website URL: ");
define("LAN_150", "Settings updated and saved into database.");
define("LAN_151", "OK");
define("LAN_152", "New Password: ");
define("LAN_153", "Re-type New Password: ");
define("LAN_154", "Save Settings");
define("LAN_155", "Update User Settings");
define("LAN_185", "You left the password field blank ");
define("LAN_308", "Real Name: ");
define("LAN_401", "Leave blank to keep existing password");
define("LAN_402", "Type path or choose avatar");
define("LAN_403", "Choose avatar");
define("LAN_404", "Please note: Any image uploaded to this server that is deemed inappropriate by the administrators will be deleted immediately.");

define("LAN_410", "Settings for");
define("LAN_411", "Update Your Settings");
define("LAN_412", "Change Your Password");
define("LAN_413", "Choose An Avatar");
define("LAN_414", "Upload Your Photograph");
define("LAN_415", "Upload your Avatar");

define("LAN_416", "Yes");
define("LAN_417", "No");

define("LAN_418", "Registration Information");
define("LAN_419", "Personal / Contact Information");
define("LAN_420", "Avatar");
define("LAN_421", "Choose site-stored avatar");
define("LAN_422", "Use remote avatar");
define("LAN_423", "Please type full address to image");
define("LAN_424", "Click button to see avatars stored on this site");
define("LAN_425", "Photograph");
define("LAN_426", "This will be shown on your profile page");
//define("LAN_427", "Submit ...");
//define("LAN_428", "News Item");
//define("LAN_429", "Link");
//define("LAN_430", "Download");
//define("LAN_431", "Article");
//define("LAN_432", "Review");

define("LAN_433", "URL to your XUP file");
define("LAN_434", "what's this?");
define("LAN_435", "XML User Protocol file");

define("LAN_SIGNUP_1", "Min.");
define("LAN_SIGNUP_2", "chars.");
define("LAN_SIGNUP_4", "Your password must be at least ");
define("LAN_SIGNUP_5", " characters long.");
define("LAN_SIGNUP_6", "Your ");
define("LAN_SIGNUP_7", " is required");

define("LAN_USET_1", "Your avatar is too wide");
define("LAN_USET_2", "Maximum allowable width is");
define("LAN_USET_3", "Your avatar is too high");
define("LAN_USET_4", "Maximum allowable height is");

// v.616
define("LAN_CUSTOMTITLE", "Custom Title");
//define("LAN_ICQNUMBER", "ICQ number must contain only numbers");

//v.617
define("LAN_408", "A user with that email address already exists. ");
define("MAX_AVWIDTH", "Maximum avatar size (wxh) is ");
define("MAX_AVHEIGHT", " x ");
// define("GIF_RESIZE", "Please resize gif image or convert to different format");
define("RESIZE_NOT_SUPPORTED", "Resize method not supported by this server. Please resize image or choose another. File has been deleted.");

// v0.7
define("LAN_USET_5", "Subscribed to");
define("LAN_USET_6", "Subscribe to our mailing-list(s) and/or sections of this site.");
define("LAN_USET_7", "Miscellaneous");
define("LAN_USET_8", "Signature / Timezone");
define("LAN_USET_9", "Some of the required fields (marked with a *) are missing from your settings.");
define("LAN_USET_10","Please update your settings now, in order to proceed.");
define("LAN_USET_11", "That user name cannot be accepted as valid, please choose a different user name");
define("LAN_USET_12", "That display name is too short. Please choose another");
define("LAN_USET_13", "Invalid characters in Username. Please choose another");
define("LAN_USET_14", "Login name too long. Please choose another");
define("LAN_USET_15", "Display name too long. Please choose another");
define("LAN_USET_16", "Tick box to delete existing photo without uploading another");
define("LAN_USET_17", "Display name already used. Please choose another");

?>

==> e107_0.7.24_full.tar.gz: e107_languages/English/lan_usersettings.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_usersettings.php $
|     $Revision: 11679 $
|     $Id: lan_usersettings.php 11679 2010-08-22 18:40:32Z e107steved $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "User Settings");

define("LAN_7", "Display Name: ");
define("LAN_8", "the name displayed on site");
define("LAN_9", "Username: ");
define("LAN_10", "the name you use to login to the site");
define("LAN_11", "the name you use to login to the site - this cannot be changed, please contact an administrator if it needs to be changed for security purposes");

define("LAN_20", "Error");
define("LAN_105", "The two passwords do not match");
define("LAN_106", "That doesn't appear to be a valid email address");
define("LAN_112", "Email Address: ");
define("LAN_113", "Hide email address?: ");
define("LAN_114", "This will prevent your email address from being displayed on site");
//define("LAN_115", "ICQ Number: ");
//define("LAN_116", "AIM Address: ");
//define("LAN_117", "MSN Messenger: ");
//define("LAN_118", "Birthday: ");
//define("LAN_119", "Location: ");
define("LAN_120", "Signature: ");
define("LAN_121", "Avatar: ");
define("LAN_122", "Timezone:");
//define("LAN_144", "Website URL: ");
define("LAN_150", "Settings updated and saved into database.");
define("LAN_151", "OK");
define("LAN_152", "New Password: ");
define("LAN_153", "Re-type New Password: ");
define("LAN_154", "Save Settings");
define("LAN_155", "Update User Settings");
define("LAN_185", "You left the password field blank ");
define("LAN_308", "Real Name: ");
define("LAN_401", "Leave blank to keep existing password");
define("LAN_402", "Type path or choose avatar");
define("LAN_403", "Choose avatar");
define("LAN_404", "Please note: Any image uploaded to this server that is deemed inappropriate by the administrators will be deleted immediately.");

define("LAN_410", "Settings for");
define("LAN_411", "Update Your Settings");
define("LAN_412", "Change Your Password");
define("LAN_413", "Choose An Avatar");
define("LAN_414", "Upload Your Photograph");
define("LAN_415", "Upload your Avatar");

define("LAN_416", "Yes");
define("LAN_417", "No");

define("LAN_418", "Registration Information");
define("LAN_419", "Personal / Contact Information");
define("LAN_420", "Avatar");
define("LAN_421", "Choose site-stored avatar");
define("LAN_422", "Use remote avatar");
define("LAN_423", "Please type full address to image");
define("LAN_424", "Click button to see avatars stored on this site");
define("LAN_425", "Photograph");
define("LAN_426", "This will be shown on your profile page");
//define("LAN_427", "Submit ...");
//define("LAN_428", "News Item");
//define("LAN_429", "Link");
//define("LAN_430", "Download");
//define("LAN_431", "Article");
//define("LAN_432", "Review");

define("LAN_433", "URL to your XUP file");
define("LAN_434", "what's this?");
define("LAN_435", "XML User Protocol file");

define("LAN_SIGNUP_1", "Min.");
define("LAN_SIGNUP_2", "chars.");
define("LAN_SIGNUP_4", "Your password must be at least ");
define("LAN_SIGNUP_5", " characters long.");
define("LAN_SIGNUP_6", "Your ");
define("LAN_SIGNUP_7", " is required");

define("LAN_USET_1", "Your avatar is too wide");
define("LAN_USET_2", "Maximum allowable width is");
define("LAN_USET_3", "Your avatar is too high");
define("LAN_USET_4", "Maximum allowable height is");

// v.616
define("LAN_CUSTOMTITLE", "Custom Title");
//define("LAN_ICQNUMBER", "ICQ number must contain only numbers");

//v.617
define("LAN_408", "A user with that email address already exists. ");
define("MAX_AVWIDTH", "Maximum avatar size (wxh) is ");
define("MAX_AVHEIGHT", " x ");
// define("GIF_RESIZE", "Please resize gif image or convert to different format");
define("RESIZE_NOT_SUPPORTED", "Resize method not supported by this server. Please resize image or choose another. File has been deleted.");

// v0.7
define("LAN_USET_5", "Subscribed to");
define("LAN_USET_6", "Subscribe to our mailing-list(s) and/or sections of this site.");
define("LAN_USET_7", "Miscellaneous");
define("LAN_USET_8", "Signature / Timezone");
define("LAN_USET_9", "Some of the required fields (marked with a *) are missing from your settings.");
define("LAN_USET_10","Please update your settings now, in order to proceed.");
define("LAN_USET_11", "That user name cannot be accepted as valid, please choose a different user name");
define("LAN_USET_12", "That display name is too short. Please choose another");
define("LAN_USET_13", "Invalid characters in Username. Please choose another");
define("LAN_USET_14", "Login name too long. Please choose another");
define("LAN_USET_15", "Display name too long. Please choose another");
define("LAN_USET_16", "Tick box to delete existing photo without uploading another");
define("LAN_USET_17", "Display name already used. Please choose another");

?>
